
/****************************************************************************
** DISCLAIMER
**
** Novell, Inc. makes no representations or warranties with respect to
** any NetWare software, and specifically disclaims any express or
** implied warranties of merchantability, title, or fitness for a
** particular purpose.
**
** Distribution of any NetWare software is forbidden without the
** express written consent of Novell, Inc.  Further, Novell reserves
** the right to discontinue distribution of any NetWare software.
**
** Novell is not responsible for lost profits or revenue, loss of use
** of the software, loss of data, costs of re-creating lost data, the
** cost of any substitute equipment or program, or claims by any party
** other than you.  Novell strongly recommends a backup be made before
** any software is installed.   Technical support for this software
** may be provided at the discretion of Novell.
****************************************************************************
**
** File:  LOCK.C
**
** Desc:  This program will take a file name on the command line in the
**				format of VOLUME:PATH and the number of locks to create and
**				create that number of physical record locks on the file.
**				The program holds the locks until a key is pressed.
**
**
** Netware API Calls:   NWCallsInit()
**											NWScanPhysicalLocksByFile()
**
** Programmers:
** Ini  Who                 Firm
** ------------------------------------------------------------------
** CRG  Calvin R. Gaisford  Novell Developer Support.
**
** History:
**
** ------------------------------------------------------------------
** 06-06-95 CRG  First code. Taken from sample by Karl Bunnell.
*/

/****************************************************************************
**   Include headers, macros, function prototypes, etc.
*/


	 /*------------------------------------------------------------------
	 **   ANSI
	 */
	 #include <conio.h>
	 #include <stdlib.h>
	 #include <stdio.h>
	 #include <string.h>
	 #include <fcntl.h>
	 #include <io.h>

	 /*------------------------------------------------------------------
	 **   NetWare
	 */
	 #include <nwcalls.h>

	 /*------------------------------------------------------------------
	 **   Defines
	 */
	 #define NWDOS

	 /*------------------------------------------------------------------
	 **   Prototypes
	 */
	 /* Entire program contained in main() */


/****************************************************************************
**   Program Start
*/
int main(int argc, char *argv[])
{
	FILE					*fileStream;
	int   				handle;
	NWFILE_HANDLE fileHandle;
	int						lockCount;
	NWCCODE    		ccode;
	NWOFFSET   		recordStartOffset;
	NWLEN					recordLength;
	NWFLAGS    		lockFlag;
	NWTICKS				timeOutLimit;

	if(argc < 3)
	{
		printf("Usage: Lock <filename (VOL:PATH)> <number of locks>\n");
		return 1;
	}

	ccode=NWCallsInit(NULL,NULL);
	if(ccode)
	{
		printf("Unable to intialize Shell/Requester tables.  Status = %04X\n");
		return 1;
	}

	lockCount = atoi(argv[2]);
	if ((handle = open(argv[1], O_CREAT | O_TEXT)) == -1)
	{
		printf("\nCannot open file");
		return 1;
	}
	fileHandle = (unsigned int)handle;
	fileStream = fdopen(fileHandle, "w");
	if (fileStream == NULL)
	{
		printf("\nfdopen failed\n");
		return 1;
	}
	recordLength = 1;
	lockFlag = 0x01;
	timeOutLimit = 0;
	recordStartOffset = 0;
	for(recordStartOffset = 0; recordStartOffset < lockCount; recordStartOffset++)
	{
		ccode = NWLogPhysicalRecord(
							/* File Handle */ fileHandle,
							/* rec. offset */ recordStartOffset,
							/* rec. Length */ recordLength,
							/* lock flags  */ lockFlag,
							/* num ticks   */ timeOutLimit);
		if(ccode)
		{
			printf("\nNWLogPhysicalRecord Returned: %X\n", ccode);
			break;
		}
	}
	printf("%d locks set on file\n", recordStartOffset);
	printf("\nPress any key to end and unlock records\n");
	getch();

	fclose(fileStream);
	return 0;
}
